<?php
/**
 * @package   AkeebaBackup
 * @copyright Copyright (c)2006-2016 Nicholas K. Dionysopoulos
 * @license   GNU General Public License version 3, or later
 */

// Protect from unauthorized access
defined('_JEXEC') or die();

/** @var  $this  \Akeeba\Backup\Admin\View\Backup\Html */

use Akeeba\Engine\Platform;

?>
{{-- Configuration Wizard pop-up --}}
@if ($this->promptForConfigurationWizard)
	@include('admin:com_akeeba/Configuration/confwiz_modal')
@endif

{{-- The Javascript of the page --}}
@include('admin:com_akeeba/Backup/script')

{{-- Obsolete PHP version warning --}}
@include('admin:com_akeeba/ControlPanel/warning_phpversion')

{{-- Backup Setup --}}
<div id="backup-setup">
	<h3>@lang('COM_AKEEBA_BACKUP_HEADER_STARTNEW')</h3>

	@if ($this->hasWarnings && !$this->unwriteableOutput)
	<div id="quirks" class="alert {{$this->hasErrors ? 'alert-error' : 'alert-warning'}}">
		<h4 class="alert-heading">
			@lang('COM_AKEEBA_BACKUP_LABEL_DETECTEDQUIRKS')
		</h4>
		<p>
			@lang('COM_AKEEBA_BACKUP_LABEL_QUIRKSLIST')
		</p>
		{{$this->warningsCell}}
	</div>
	@endif

	@if($this->unwriteableOutput)
	<div id="akeeba-fatal-outputdirectory" class="alert alert-error">
		<p>
			@lang('COM_AKEEBA_BACKUP_ERROR_UNWRITABLEOUTPUT_' . ($this->autoStart ? 'AUTOBACKUP' : 'NORMALBACKUP'))
		</p>
		<p>
			@sprintf(
				'COM_AKEEBA_BACKUP_ERROR_UNWRITABLEOUTPUT_COMMON',
				'index.php?option=com_akeeba&view=Configuration',
				'https://www.akeebabackup.com/warnings/q001.html'
			)
		</p>
	</div>
	@endif

	<form action="index.php" method="post" name="flipForm" id="flipForm"
		  class="well akeeba-formstyle-reset form-inline"
		  autocomplete="off">
		<input type="hidden" name="option" value="com_akeeba"/>
		<input type="hidden" name="view" value="Backup"/>
		<input type="hidden" name="returnurl" value="{{{$this->returnURL}}}"/>
		<input type="hidden" name="description" id="flipDescription" value=""/>
		<input type="hidden" name="comment" id="flipComment" value=""/>
		<input type="hidden" name="@token()" value="1"/>

		<label>
			@lang('COM_AKEEBA_CPANEL_PROFILE_TITLE'): #{{$this->profileid}}
		</label>
		@jhtml('select.genericlist', $this->profileList, 'profileid', 'onchange="akeeba.Backup.flipProfile();" class="advancedSelect"', 'value', 'text', $this->profileid)
		<button class="btn" onclick="akeeba.Backup.flipProfile(); return false;">
			<span class="icon-refresh"></span>
			@lang('COM_AKEEBA_CPANEL_PROFILE_BUTTON')
		</button>
	</form>

	<form id="dummyForm" class="form-horizontal" style="display: {{$this->unwriteableOutput ? 'none' : 'block'}};">
		<div class="control-group">
			<label class="control-label" for="backup-description">
				@lang('COM_AKEEBA_BACKUP_LABEL_DESCRIPTION')
			</label>
			<div class="controls">
				<input type="text" name="description" value="{{{$this->description}}}"
					maxlength="255" size="80" id="backup-description" class="input-xxlarge" autocomplete="off" />
				<span class="help-block">@lang('COM_AKEEBA_BACKUP_LABEL_DESCRIPTION_HELP')</span>
			</div>
		</div>

		@if($this->showJPSPassword)
		<div class="control-group">
			<label class="control-label" for="jpskey">
				@lang('COM_AKEEBA_CONFIG_JPS_KEY_TITLE')
			</label>
			<div class="controls">
				<input type="password" name="jpskey" value="{{{$this->jpsPassword}}}" size="50" id="jpskey" autocomplete="off" />
				<span class="help-block">@lang('COM_AKEEBA_CONFIG_JPS_KEY_DESCRIPTION')</span>
			</div>
		</div>
		@endif

		@if(AKEEBA_PRO && $this->showANGIEPassword)
		<div class="control-group">
			<label class="control-label" for="angiekey">
				@lang('COM_AKEEBA_CONFIG_ANGIE_KEY_TITLE')
			</label>
			<div class="controls">
				<input type="password" name="angiekey" value="{{{$this->ANGIEPassword}}}"  size="50" id="angiekey" autocomplete="off" />
				<span class="help-block">@lang('COM_AKEEBA_CONFIG_ANGIE_KEY_DESCRIPTION')</span>
			</div>
		</div>
		@endif

		<div class="control-group">
			<label class="control-label" for="comment">
				@lang('COM_AKEEBA_BACKUP_LABEL_COMMENT')
			</label>
			<div class="controls">
				<textarea id="comment" rows="5" cols="73" class="input-xxlarge">{{$this->comment}}</textarea>
				<span class="help-block">@lang('COM_AKEEBA_BACKUP_LABEL_COMMENT_HELP')</span>
			</div>
		</div>

		<div class="form-actions">
			<button class="btn btn-primary" id="backup-start" onclick="return false;">
				<span class="icon-play icon-white"></span>
				@lang('COM_AKEEBA_BACKUP_LABEL_START')
			</button>

            <span class="btn btn-warning" id="backup-default">
                <span class="icon-refresh icon-white"></span>
                @lang('COM_AKEEBA_BACKUP_LABEL_RESTORE_DEFAULT')
            </span>
		</div>
	</form>
</div>

{{-- Warning for having set an ANGIE password --}}
<div id="angie-password-warning" class="alert alert-danger alert-error" style="display: none">
    <h1>@lang('COM_AKEEBA_BACKUP_ANGIE_PASSWORD_WARNING_HEADER')</h1>
    <p>@lang('COM_AKEEBA_BACKUP_ANGIE_PASSWORD_WARNING_1')</p>
    <p>@lang('COM_AKEEBA_BACKUP_ANGIE_PASSWORD_WARNING_2')</p>
    <p>@lang('COM_AKEEBA_BACKUP_ANGIE_PASSWORD_WARNING_3')</p>
</div>

{{-- Backup in progress --}}
<div id="backup-progress-pane" style="display: none">
	<div class="alert">
		<span class="icon-warning-circle"></span>
		@lang('COM_AKEEBA_BACKUP_TEXT_BACKINGUP')
	</div>

	<h3>@lang('COM_AKEEBA_BACKUP_LABEL_PROGRESS')</h3>

	<div id="backup-progress-content">
		<div id="backup-steps"></div>
		<div id="backup-status" class="well">
			<div id="backup-step"></div>
			<div id="backup-substep"></div>
		</div>
		<div id="backup-percentage" class="progress">
			<div class="bar" style="width: 0"></div>
		</div>
		<div id="response-timer">
			<div class="color-overlay"></div>
			<div class="text"></div>
		</div>
	</div>
	<span id="ajax-worker"></span>
</div>

{{-- Backup complete --}}
<div id="backup-complete" style="display: none">
	<div class="alert alert-success alert-block">
		<h2 class="alert-heading">
			@if(empty($this->returnURL))
			@lang('COM_AKEEBA_BACKUP_HEADER_BACKUPFINISHED')
			@else
			@lang('COM_AKEEBA_BACKUP_HEADER_BACKUPWITHRETURNURLFINISHED')
			@endif
		</h2>
		<div id="finishedframe">
			<p>
				@if(empty($this->returnURL))
					@lang('COM_AKEEBA_BACKUP_TEXT_CONGRATS')
				@else
					@lang('COM_AKEEBA_BACKUP_TEXT_PLEASEWAITFORREDIRECTION')
				@endif
			</p>

			@if(empty($this->returnURL))
			<a class="btn btn-primary btn-large" href="<?php echo JUri::base() ?>index.php?option=com_akeeba&view=Manage">
				<span class="icon-stack icon-white"></span>
				@lang('COM_AKEEBA_BUADMIN')
			</a>
			<a class="btn" id="ab-viewlog-success" href="<?php echo JUri::base() ?>index.php?option=com_akeeba&view=Log">
				<span class="icon-list"></span>
				@lang('COM_AKEEBA_LOG')
			</a>
			@endif
		</div>
	</div>
</div>

{{-- Backup warnings --}}
<div id="backup-warnings-panel" style="display:none">
	<div class="alert">
		<h3 class="alert-heading">
			@lang('COM_AKEEBA_BACKUP_LABEL_WARNINGS')
		</h3>
		<div id="warnings-list">
		</div>
	</div>
</div>

{{-- Backup retry after error --}}
<div id="retry-panel" style="display: none">
	<div class="alert alert-warning">
		<h3 class="alert-heading">
			@lang('COM_AKEEBA_BACKUP_HEADER_BACKUPRETRY')
		</h3>
		<div id="retryframe">
			<p>@lang('COM_AKEEBA_BACKUP_TEXT_BACKUPFAILEDRETRY')</p>
			<p>
				<strong>
					@lang('COM_AKEEBA_BACKUP_TEXT_WILLRETRY')
					<span id="akeeba-retry-timeout">0</span>
					@lang('COM_AKEEBA_BACKUP_TEXT_WILLRETRYSECONDS')
				</strong>
				<br/>
				<button class="btn btn-danger btn-small" onclick="akeeba.Backup.cancelResume(); return false;">
					<span class="icon-cancel"></span>
					@lang('COM_AKEEBA_MULTIDB_GUI_LBL_CANCEL')
				</button>
				<button class="btn btn-success btn-small" onclick="akeeba.Backup.resumeBackup(); return false;">
					<span class="icon-redo"></span>
					@lang('COM_AKEEBA_BACKUP_TEXT_BTNRESUME')
				</button>
			</p>

			<p>@lang('COM_AKEEBA_BACKUP_TEXT_LASTERRORMESSAGEWAS')</p>
			<p id="backup-error-message-retry"></p>
		</div>
	</div>
</div>

{{-- Backup error (halt) --}}
<div id="error-panel" style="display: none">
	<div class="alert alert-error">
		<h3 class="alert-heading">
			@lang('COM_AKEEBA_BACKUP_HEADER_BACKUPFAILED')
		</h3>
		<div id="errorframe">
			<p>
				@lang('COM_AKEEBA_BACKUP_TEXT_BACKUPFAILED')
			</p>
			<p id="backup-error-message"></p>

			<p>
				@lang('COM_AKEEBA_BACKUP_TEXT_READLOGFAIL' . (AKEEBA_PRO ? 'PRO' : ''))
			</p>

			<div class="alert alert-block alert-info" id="error-panel-troubleshooting">
				<p>
					@if(AKEEBA_PRO)
					@lang('COM_AKEEBA_BACKUP_TEXT_RTFMTOSOLVEPRO')
					@endif

					@sprintf('COM_AKEEBA_BACKUP_TEXT_RTFMTOSOLVE', 'https://www.akeebabackup.com/documentation/troubleshooter/abbackup.html?utm_source=akeeba_backup&utm_campaign=backuperrorlink')
				</p>
				<p>
					@if(AKEEBA_PRO)
					@sprintf('COM_AKEEBA_BACKUP_TEXT_SOLVEISSUE_PRO', 'https://www.akeebabackup.com/support.html?utm_source=akeeba_backup&utm_campaign=backuperrorpro')
					@else
					@sprintf('COM_AKEEBA_BACKUP_TEXT_SOLVEISSUE_CORE', 'https://www.akeebabackup.com/subscribe.html?utm_source=akeeba_backup&utm_campaign=backuperrorcore','https://www.akeebabackup.com/support.html?utm_source=akeeba_backup&utm_campaign=backuperrorcore')
					@endif

					@sprintf('COM_AKEEBA_BACKUP_TEXT_SOLVEISSUE_LOG', 'index.php?option=com_akeeba&view=Log')
				</p>
			</div>

			@if(AKEEBA_PRO)
			<a class="btn btn-large btn-success" id="ab-alice-error" href="index.php?option=com_akeeba&view=Alice">
				<span class="icon-wand icon-white"></span>
				@lang('COM_AKEEBA_BACKUP_ANALYSELOG')
			</a>
			@endif

			<button class="btn btn-large btn-primary" onclick="window.location='https://www.akeebabackup.com/documentation/troubleshooter/abbackup.html?utm_source=akeeba_backup&utm_campaign=backuperrorbutton'; return false;">
				<span class="icon-book icon-white"></span>
				@lang('COM_AKEEBA_BACKUP_TROUBLESHOOTINGDOCS')
			</button>
			<a class="btn" id="ab-viewlog-error" href="index.php?option=com_akeeba&view=Log">
				<span class="icon-list"></span>
				@lang('COM_AKEEBA_LOG')
			</a>
		</div>
	</div>
</div>